library IEEE;
use IEEE.std_logic_1164.all;
--
-- pragma translate_off
library UNISIM;
use UNISIM.VCOMPONENTS.ALL;
-- pragma translate_on
--
entity SRLC128E_MACRO is
  port (
  	D    : in std_logic;
        CE   : in std_logic; 
        CLK  : in std_logic;
        A0   : in std_logic;
        A1   : in std_logic;
        A2   : in std_logic;
        A3   : in std_logic;
        A4   : in std_logic;
        A5   : in std_logic;
        A6   : in std_logic;
        Q    : out std_logic;
        Q127  : out std_logic 
       ); 
end SRLC128E_MACRO;
--
architecture SRLC128E_MACRO_arch of SRLC128E_MACRO is
--
-- Components Declarations:
component SRLC16E 
  port (
  	D    : in std_logic;
        CE   : in std_logic;
        CLK  : in std_logic;
        A0   : in std_logic;
        A1   : in std_logic;
        A2   : in std_logic;
        A3   : in std_logic;
        Q    : out std_logic;
        Q15  : out std_logic
	); 
end component;
--
component MUXF5_L
  port (
  	I0   : in std_logic;
  	I1   : in std_logic;
  	S    : in std_logic;
  	LO    : out std_logic
  	);
end component;
--
component MUXF6_L
  port (
  	I0   : in std_logic;
  	I1   : in std_logic;
  	S    : in std_logic;
  	LO    : out std_logic
  	);
end component;
--
component MUXF7
  port (
  	I0   : in std_logic;
  	I1   : in std_logic;
  	S    : in std_logic;
  	O    : out std_logic
  	);
end component;
--
-- signal declarations
signal SHIFT_CHAIN : std_logic_vector (8 downto 0);
signal SHIFT_OUT : std_logic_vector (7 downto 0);
signal F5_OUT : std_logic_vector (3 downto 0);
signal F6_OUT : std_logic_vector (1 downto 0);
--
begin
--
SHIFT_CHAIN(0) <= D;
--
-- ShiftRegister Instantiations
U_SRLC16E_INST: for i in 0 to 7 generate
-- 
U_SRLC16E: SRLC16E
  port map (
	D      => SHIFT_CHAIN(i),
	CE     => CE, 
	CLK    => CLK, 
	A0     => A0, 
	A1     => A1, 
	A2     => A2, 
	A3     => A3, 
	Q      => SHIFT_OUT(i),
	Q15    => SHIFT_CHAIN (i+1)  
	);
end generate;
--
Q127 <= SHIFT_CHAIN(8);
--
-- Local Slice output
U_MUXF5_INST: for i in 0 to 3 generate
--
U_MUXF5: MUXF5_L
  port map (
  	I0     => SHIFT_OUT(i*2),
  	I1     => SHIFT_OUT(i*2 + 1),
  	S      => A4,
  	LO     => F5_OUT(i)
  	);	
end generate;	
--
U_MUXF6_INST: for i in 0 to 1 generate
--
U_MUXF6: MUXF6_L
  port map (
  	I0     => F5_OUT(i*2),
  	I1     => F5_OUT(i*2 + 1),
  	S      => A5,
  	LO     => F6_OUT(i)
  	);	
end generate;	
--
U_MUXF7: MUXF7
  port map (
         I0    => F6_OUT(0),
         I1    => F6_OUT(1),
         S     => A6,
         O     => Q
         );
--		
end SRLC128E_MACRO_arch;
------------------------------------------------------------------------------------------------


